@@ -6,69 +6,39 @@
 
 """Command-line interface.
 
-Use 'gas' + COMMAND in terminal to operate on datasets.
+Use ``gas <command>`` in terminal to operate on datasets.
 
-Use 'gas config' to  configure environment.
+Use ``gas auth`` to authenticate the accessKey of gas.
 
-Use 'gas ls' to list data.
+Use ``gas branch`` to list, create or delete branches.
 
-Use 'gas draft' to operate a draft.
+Use ``gas commit`` to commit drafts.
 
-Use 'gas branch' to operate a branch.
+Use ``gas config`` to configure the options when using gas CLI.
+
+Use ``gas cp`` to copy local data to a remote path.
+
+Use ``gas dataset`` to list, create or delete datasets.
+
+Use ``gas draft`` to list or create drafts.
+
+Use ``gas log`` to show commit logs.
+
+Use ``gas ls`` to list data under the path.
+
+Use ``gas rm`` to remove the remote data.
+
+Use ``gas tag`` to list, create or delete tags.
 
 """
 
-from typing import Any, Dict, Iterable, Optional, Tuple
+from functools import partial
+from typing import Dict, Iterable, Optional, Tuple
 
 import click
 
 from .. import __version__
-
-
-class DeprecatedCommand(click.Command):
-    """Customized ``click.Command`` wrapper class for deprecated CLI commands.
-
-    Arguments:
-        args: The positional arguments pass to ``click.Command``.
-        since: The version the function is deprecated.
-        removed_in: The version the function will be removed in.
-        substitute: The substitute command.
-        kwargs: The keyword arguments pass to ``click.Command``.
-
-    """
-
-    def __init__(
-        self,
-        *args: Any,
-        since: str,
-        removed_in: Optional[str] = None,
-        substitute: Optional[str] = None,
-        **kwargs: Any,
-    ):
-        super().__init__(*args, **kwargs)
-
-        messages = [
-            f'DeprecationWarning: The command "{self.name}" is deprecated since version {since}.'
-        ]
-        if removed_in:
-            messages.append(f'It will be removed in version "{removed_in}".')
-        if substitute:
-            messages.append(f'Use "{substitute}" instead.')
-
-        self.deprecated_message = " ".join(messages)
-
-    def invoke(self, ctx: click.Context) -> Any:
-        """This invokes the command to print the deprecated message.
-
-        Arguments:
-            ctx: The click Context.
-
-        Returns:
-            The invoke result of ``click.Command``.
-
-        """
-        click.secho(self.deprecated_message, fg="red", err=True)
-        return super().invoke(ctx)
+from .custom import CustomCommand, DeprecatedOption, DeprecatedOptionsCommand
 
 
 @click.group()
@@ -93,7 +63,7 @@ class DeprecatedCommand(click.Command):
 @click.option("-d", "--debug", is_flag=True, help="Debug mode.")
 @click.pass_context
 def cli(ctx: click.Context, access_key: str, url: str, profile_name: str, debug: bool) -> None:
-    """You can use 'gas' + COMMAND to operate on your dataset.\f
+    """You can use ``gas <command>`` to operate on your datasets.\f
 
     Arguments:
         ctx: The context to be passed as the first argument.
@@ -108,53 +78,16 @@ def cli(ctx: click.Context, access_key: str, url: str, profile_name: str, debug:
     _implement_cli(ctx, access_key, url, profile_name, debug)
 
 
-@cli.command(
-    cls=DeprecatedCommand,
-    hidden=True,
-    since="v1.5.0",
-    removed_in="v1.8.0",
-    substitute="gas dataset tb:[dataset_name]",
+command = partial(cli.command, cls=CustomCommand)
+
+
+@command(
+    synopsis=(
+        "$ gas ls                                       # List all the datasets.",
+        "$ gas ls tb:<dataset_name>                     # List segments of a dataset.",
+        "$ gas ls tb:<dataset_name>:<segment_name>      # List files of a segment.",
+    )
 )
-@click.argument("name", type=str)
-@click.pass_obj
-def create(obj: Dict[str, str], name: str) -> None:
-    """Create a dataset.\f
-
-    Arguments:
-        obj: A dict including config information.
-        name: The name of the dataset to be created, like "tb:KITTI".
-
-    """  # noqa: D301,D415
-    from .dataset import _implement_dataset
-
-    _implement_dataset(obj, name, is_delete=False, yes=False)
-
-
-@cli.command(
-    cls=DeprecatedCommand,
-    hidden=True,
-    since="v1.5.0",
-    removed_in="v1.8.0",
-    substitute="gas dataset -d tb:[dataset_name]",
-)
-@click.argument("name", type=str)
-@click.option("-y", "--yes", is_flag=True, help="Confirm to delete the dataset completely.")
-@click.pass_obj
-def delete(obj: Dict[str, str], name: str, yes: bool) -> None:
-    """Delete a dataset.\f
-
-    Arguments:
-        obj: A dict including config info.
-        name: The name of the dataset to be deleted, like "tb:KITTI".
-        yes: Confirm to delete the dataset completely.
-
-    """  # noqa: D301,D415
-    from .dataset import _implement_dataset
-
-    _implement_dataset(obj, name, is_delete=True, yes=yes)
-
-
-@cli.command()
 @click.argument("tbrn", type=str, default="")
 @click.option(
     "-a", "--all", "list_all_files", is_flag=True, help="List all files under the segment."
@@ -176,31 +109,43 @@ def ls(  # pylint: disable=invalid-name
     _implement_ls(obj, tbrn, list_all_files)
 
 
-@cli.command()
-@click.argument("arg1", type=str, default="", metavar="[accessKey or 'editor']")
-@click.argument("arg2", type=str, default="", metavar="[editor name]")
-@click.pass_obj
-def config(obj: Dict[str, str], arg1: str, arg2: str) -> None:
-    """Configure the accessKey of gas or the editor to be launched when using gas.\f
+@command(
+    synopsis=(
+        "$ gas config [key]                # Show the config.",
+        "$ gas config <key> <value>        # Set the config.",
+        "$ gas config -u [key]             # Unset the config.",
+    )
+)
+@click.argument("key", type=str, default="")
+@click.argument("value", type=str, default="")
+@click.option("-u", "--unset", is_flag=True, help="Unset the config option")
+def config(key: str, value: str, unset: bool) -> None:
+    """Configure the options when using gas CLI.\f
 
     Arguments:
-        obj: A dict contains config information.
-        arg1: The accessKey of gas to write into config file or the keyword "editor".
-        arg2: The URL of gas to write into config file or the editor to be lanched.
+        key: The option key.
+        value: The option value.
+        unset: Whether to unset the option.
 
     """  # noqa: D301,D415
     from .config import _implement_config
 
-    _implement_config(obj, arg1, arg2)
+    _implement_config(key, value, unset)
 
 
-@cli.command()
+@command(
+    synopsis=(
+        "$ gas dataset                                  # List all the datasets.",
+        "$ gas dataset tb:<dataset_name>                # Create a dataset.",
+        "$ gas dataset -d [-y] tb:<dataset_name>        # Delete a dataset.",
+    )
+)
 @click.argument("tbrn", type=str, default="")
 @click.option("-d", "--delete", "is_delete", is_flag=True, help="Delete TensorBay dataset")
 @click.option("-y", "--yes", is_flag=True, help="Confirm to delete the dataset completely.")
 @click.pass_obj
 def dataset(obj: Dict[str, str], tbrn: str, is_delete: bool, yes: bool) -> None:
-    """Work with TensorBay datasets\f
+    """List, create or delete datasets.\f
 
     Arguments:
         obj: A dict including config information.
@@ -214,39 +159,61 @@ def dataset(obj: Dict[str, str], tbrn: str, is_delete: bool, yes: bool) -> None:
     _implement_dataset(obj, tbrn, is_delete, yes)
 
 
-@cli.command()
+@command(
+    cls=DeprecatedOptionsCommand,
+    synopsis=(
+        "$ gas draft -l tb:<dataset_name>                                # List drafts.",
+        "$ gas draft tb:<dataset_name>[@<branch_name>] [-m <message>]    # Create a draft.",
+    ),
+)
 @click.argument("tbrn", type=str)
 @click.option("-l", "--list", "is_list", is_flag=True, help="List the drafts.")
-@click.option("-t", "--title", type=str, default="", help="The title of the draft.")
+@click.option(
+    "-m",
+    "--message",
+    "-t",
+    "--title",
+    type=str,
+    multiple=True,
+    default=(),
+    help="The message of the draft.",
+    deprecated=("-t", "--title"),
+    preferred="-m",
+    since="v1.8.0",
+    removed_in="v1.10.0",
+    cls=DeprecatedOption,
+)
 @click.pass_obj
 def draft(
     obj: Dict[str, str],
     tbrn: str,
     is_list: bool,
-    title: str,
+    message: Tuple[str, ...],
 ) -> None:
-    """Work with draft.\f
+    """List or create drafts.\f
 
     Arguments:
         obj: A dict contains config information.
         tbrn: The tbrn of the dataset.
         is_list: Whether to list the drafts.
-        title: The title of the draft.
+        message: The message of the draft.
 
     """  # noqa: D301,D415
     from .draft import _implement_draft
 
-    _implement_draft(obj, tbrn, is_list, title)
+    _implement_draft(obj, tbrn, is_list, message)
 
 
-@cli.command()
+@command(
+    synopsis=("$ gas commit tb:<dataset_name>#<draft_number> [-m <message>]      # Commit a draft.")
+)
 @click.argument("tbrn", type=str)
 @click.option(
     "-m", "--message", type=str, multiple=True, default=(), help="The message of the commit."
 )
 @click.pass_obj
 def commit(obj: Dict[str, str], tbrn: str, message: Tuple[str, ...]) -> None:
-    """Work with commit.\f
+    """Commit drafts.\f
 
     Arguments:
         obj: A dict contains config information.
@@ -259,7 +226,18 @@ def commit(obj: Dict[str, str], tbrn: str, message: Tuple[str, ...]) -> None:
     _implement_commit(obj, tbrn, message)
 
 
-@cli.command()
+@command(
+    synopsis=(
+        "# Upload a file.",
+        "$ gas cp <local_path> tb:<dataset_name>#<draft_number>:<segment_name>[://<remote_path]",
+        "",
+        "# Upload files.",
+        "$ gas cp <local_path1> [local_path2 ...] tb:<dataset_name>#<draft_number>:<segment_name>",
+        "",
+        "# Upload files in a folder.",
+        "$ gas cp -r <local_folder> tb:<dataset_name>#<draft_number>:<segment_name>",
+    )
+)
 @click.argument("local_paths", type=str, nargs=-1)
 @click.argument("tbrn", type=str, nargs=1)
 @click.option(
@@ -298,7 +276,15 @@ def cp(  # pylint: disable=invalid-name, too-many-arguments
     _implement_cp(obj, local_paths, tbrn, is_recursive, jobs, skip_uploaded_files)
 
 
-@cli.command()
+@command(
+    synopsis=(
+        "# Remove a segment.",
+        "$ gas rm -r tb:<dataset_name>#<draft_number>:<segment_name>",
+        "",
+        "# Remove a file.",
+        "$ gas rm tb:<dataset_name>#<draft_number>:<segment_name>://<remote_path>",
+    )
+)
 @click.argument("tbrn", type=str)
 @click.option(
     "-r", "--recursive", "is_recursive", is_flag=True, help="Remove directories recursively."
@@ -320,14 +306,20 @@ def rm(  # pylint: disable=invalid-name, too-many-arguments
     _implement_rm(obj, tbrn, is_recursive)
 
 
-@cli.command()
+@command(
+    synopsis=(
+        "$ gas branch tb:<dataset_name> [--verbose]                      # List branches.",
+        "$ gas branch tb:<dataset_name>[@<revision>] <branch_name>       # Create a branch.",
+        "$ gas branch -d tb:<dataset_name>@<branch_name>                 # Delete a branch.",
+    )
+)
 @click.argument("tbrn", type=str)
 @click.argument("name", type=str, default="")
 @click.option("-v", "--verbose", is_flag=True, help="Show short commit id and commit message.")
 @click.option("-d", "--delete", "is_delete", is_flag=True, help="Delete the branch")
 @click.pass_obj
 def branch(obj: Dict[str, str], tbrn: str, name: str, verbose: bool, is_delete: bool) -> None:
-    """Work with branch.\f
+    """List, create or delete branches.\f
 
     Arguments:
         obj: A dict contains config information.
@@ -342,13 +334,19 @@ def branch(obj: Dict[str, str], tbrn: str, name: str, verbose: bool, is_delete:
     _implement_branch(obj, tbrn, name, verbose, is_delete)
 
 
-@cli.command()
+@command(
+    synopsis=(
+        "$ gas tag tb:<dataset_name>                            # List tags.",
+        "$ gas tag tb:<dataset_name>[@<revision>] <tag_name>    # Create a tag.",
+        "$ gas tag -d tb:<dataset_name>@<tag_name>              # Delete a tag.",
+    )
+)
 @click.argument("tbrn", type=str)
 @click.argument("name", type=str, default="")
 @click.option("-d", "--delete", "is_delete", is_flag=True, help="Delete the tag.")
 @click.pass_obj
 def tag(obj: Dict[str, str], tbrn: str, name: str, is_delete: bool) -> None:
-    """Work with tag.\f
+    """List, create or delete tags.\f
 
     Arguments:
         obj: A dict contains config information.
@@ -362,7 +360,13 @@ def tag(obj: Dict[str, str], tbrn: str, name: str, is_delete: bool) -> None:
     _implement_tag(obj, tbrn, name, is_delete)
 
 
-@cli.command()
+@command(
+    synopsis=(
+        "$ gas log tb:<dataset_name>[@<revision>]               # Show commit logs.",
+        "$ gas log -n <number> tb:<dataset_name>[@<revision>]   # Show up to <number> commit logs.",
+        "$ gas log --oneline tb:<dataset_name>[@<revision>]     # Show oneline commit logs.",
+    )
+)
 @click.argument("tbrn", type=str)
 @click.option(
     "-n", "--max-count", type=int, default=None, help="Limit the max number of commits to be showed"
@@ -389,5 +393,38 @@ def log(
     _implement_log(obj, tbrn, max_count, oneline)
 
 
+@command(
+    synopsis=(
+        "$ gas auth                      # Interactive authentication.",
+        "$ gas auth <AccessKey>          # Authenticate with AccessKey.",
+        "$ gas auth -g [-a]              # Get the authentication info.",
+        "$ gas auth -u [-a]              # Unset the authentication info.",
+    )
+)
+@click.argument("arg1", type=str, default="", metavar="accessKey")
+@click.argument("arg2", type=str, default="", metavar="")
+@click.option("-g", "--get", is_flag=True, help="Get the accesskey of the profile")
+@click.option("-u", "--unset", is_flag=True, help="Unset the accesskey of the profile")
+@click.option("-a", "--all", "is_all", is_flag=True, help="All the auth info")
+@click.pass_obj
+def auth(  # pylint: disable=too-many-arguments
+    obj: Dict[str, str], arg1: str, arg2: str, get: bool, unset: bool, is_all: bool
+) -> None:
+    """Authenticate the accessKey of gas.\f
+
+    Arguments:
+        obj: A dict contains config information.
+        arg1: The accessKey or the url of gas for the authentication.
+        arg2: The accessKey of gas for the authentication if arg1 is url.
+        get: Whether to get the accesskey of the profile.
+        unset: Whether to unset the accesskey of the profile.
+        is_all: All the auth info or not.
+
+    """  # noqa: D301,D415
+    from .auth import _implement_auth
+
+    _implement_auth(obj, arg1, arg2, get, unset, is_all)
+
+
 if __name__ == "__main__":
     cli()  # pylint: disable=no-value-for-parameter
