@@ -25,21 +25,21 @@ Please refer to :class:`~tensorbay.dataset.dataset.FusionDataset` for more infor
 import logging
 from typing import TYPE_CHECKING, Any, Dict, Generator, Iterable, Iterator, Optional, Tuple, Union
 
-from ..dataset import Data, Frame, FusionSegment, Notes, Segment
+from ..dataset import AuthData, Data, Frame, FusionSegment, Notes, RemoteData, Segment
 from ..exception import (
     FrameError,
+    InvalidParamsError,
     NameConflictError,
     OperationError,
     ResourceNotExistError,
-    StatusError,
 )
 from ..label import Catalog
-from ..utility import DefaultValueDeprecated
+from .lazy import PagingList
 from .log import UPLOAD_SEGMENT_RESUME_TEMPLATE
-from .requests import Client, PagingList, Tqdm, multithread_upload
-from .segment import FusionSegmentClient, SegmentClient
+from .requests import Tqdm, multithread_upload
+from .segment import _STRATEGIES, FusionSegmentClient, SegmentClient
 from .status import Status
-from .struct import Branch, Commit, Draft, Tag
+from .version import VersionControlClient
 
 if TYPE_CHECKING:
     from .gas import GAS
@@ -47,7 +47,7 @@ if TYPE_CHECKING:
 logger = logging.getLogger(__name__)
 
 
-class DatasetClientBase:  # pylint: disable=too-many-public-methods
+class DatasetClientBase(VersionControlClient):
     """This class defines the basic concept of the dataset client.
 
     A :class:`DatasetClientBase` contains the information needed for
@@ -58,107 +58,25 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
     Arguments:
         name: Dataset name.
         dataset_id: Dataset ID.
-        gas_client: The initial client to interact between local and TensorBay.
+        gas: The initial client to interact between local and TensorBay.
+        status: The version control status of the dataset.
 
     Attributes:
         name: Dataset name.
         dataset_id: Dataset ID.
-        status: The status of the dataset client.
+        status: The version control status of the dataset.
 
     """
 
-    _client: Client
-
-    def __init__(self, name: str, dataset_id: str, gas_client: "GAS", *, status: Status) -> None:
+    def __init__(self, name: str, dataset_id: str, gas: "GAS", *, status: Status) -> None:
+        super().__init__(dataset_id, gas, status=status)
         self._name = name
-        self._dataset_id = dataset_id
-        self._gas_client = gas_client
-        self._client = gas_client._client  # pylint: disable=protected-access
-        self._status = status
-
-    def _commit(self, title: str, description: str, tag: Optional[str] = None) -> str:
-        post_data: Dict[str, Any] = {"title": title}
-        post_data.update(self._status.get_status_info())
-
-        if description:
-            post_data["description"] = description
-
-        if tag:
-            post_data["tag"] = tag
-
-        response = self._client.open_api_do("POST", "commits", self.dataset_id, json=post_data)
-        return response.json()["commitId"]  # type: ignore[no-any-return]
-
-    def _create_draft(self, title: Optional[str], branch_name: Optional[str] = None) -> int:
-        post_data: Dict[str, Any] = {}
-
-        if title:
-            post_data["title"] = title
-
-        if branch_name:
-            post_data["branchName"] = branch_name
-
-        response = self._client.open_api_do("POST", "drafts", self.dataset_id, json=post_data)
-        return response.json()["draftNumber"]  # type: ignore[no-any-return]
-
-    def _generate_drafts(self, offset: int = 0, limit: int = 128) -> Generator[Draft, None, int]:
-        params = {"offset": offset, "limit": limit}
-        response = self._client.open_api_do("GET", "drafts", self.dataset_id, params=params).json()
-
-        for item in response["drafts"]:
-            yield Draft.loads(item)
-
-        return response["totalCount"]  # type: ignore[no-any-return]
-
-    def _generate_commits(
-        self, revision: Optional[str] = None, offset: int = 0, limit: int = 128
-    ) -> Generator[Commit, None, int]:
-        params: Dict[str, Any] = {"offset": offset, "limit": limit}
-        if revision:
-            params["commit"] = revision
-
-        response = self._client.open_api_do("GET", "commits", self.dataset_id, params=params).json()
-
-        for item in response["commits"]:
-            yield Commit.loads(item)
-
-        return response["totalCount"]  # type: ignore[no-any-return]
-
-    def _generate_tags(
-        self, name: Optional[str] = None, offset: int = 0, limit: int = 128
-    ) -> Generator[Tag, None, int]:
-        params: Dict[str, Any] = {"offset": offset, "limit": limit}
-        if name:
-            params["name"] = name
-
-        response = self._client.open_api_do("GET", "tags", self.dataset_id, params=params).json()
-
-        for item in response["tags"]:
-            yield Tag.loads(item)
-
-        return response["totalCount"]  # type: ignore[no-any-return]
-
-    def _generate_branches(
-        self, name: Optional[str] = None, offset: int = 0, limit: int = 128
-    ) -> Generator[Branch, None, int]:
-        params: Dict[str, Any] = {"offset": offset, "limit": limit}
-        if name:
-            params["name"] = name
-
-        response = self._client.open_api_do(
-            "GET", "branches", self.dataset_id, params=params
-        ).json()
-
-        for item in response["branches"]:
-            yield Branch.loads(item)
-
-        return response["totalCount"]  # type: ignore[no-any-return]
 
     def _create_segment(self, name: str) -> None:
         post_data: Dict[str, Any] = {"name": name}
         post_data.update(self._status.get_status_info())
 
-        self._client.open_api_do("POST", "segments", self.dataset_id, json=post_data)
+        self._client.open_api_do("POST", "segments", self._dataset_id, json=post_data)
 
     def _list_segments(self, offset: int = 0, limit: int = 128) -> Dict[str, Any]:
         params: Dict[str, Any] = self._status.get_status_info()
@@ -178,16 +96,36 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
 
         return response["totalCount"]  # type: ignore[no-any-return]
 
-    def _delete_branch(self, name: str) -> None:
-        """Delete a branch without checking current branch.
+    def _copy_segment(
+        self,
+        source_name: str,
+        target_name: str,
+        *,
+        source_client: Union[None, "DatasetClient", "FusionDatasetClient"],
+        strategy: str = "abort",
+    ) -> None:
+        if strategy not in _STRATEGIES:
+            raise InvalidParamsError(param_name="strategy", param_value=strategy)
 
-        Arguments:
-            name: The name of the branch to be deleted.
+        source = {"segmentName": source_name}
 
-        """
-        delete_data: Dict[str, Any] = {"name": name}
+        if not source_client:
+            if source_name == target_name:
+                raise OperationError("Copying the segment to the same location is not allowed")
+        else:
+            source["id"] = source_client.dataset_id
+            source.update(source_client.status.get_status_info())
 
-        self._client.open_api_do("DELETE", "branches", self.dataset_id, json=delete_data)
+        self._status.check_authority_for_draft()
+
+        post_data: Dict[str, Any] = {
+            "strategy": strategy,
+            "source": source,
+            "segmentName": target_name,
+        }
+        post_data.update(self._status.get_status_info())
+
+        self._client.open_api_do("POST", "segments?copy", self._dataset_id, json=post_data)
 
     @property
     def name(self) -> str:
@@ -199,326 +137,6 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
         """
         return self._name
 
-    @property
-    def dataset_id(self) -> str:
-        """Return the TensorBay dataset ID.
-
-        Returns:
-            The TensorBay dataset ID.
-
-        """
-        return self._dataset_id
-
-    @property
-    def status(self) -> Status:
-        """Return the status of the dataset client.
-
-        Returns:
-            The status of the dataset client.
-
-        """
-        return self._status
-
-    @DefaultValueDeprecated("title", since="v1.6.0", removed_in="v1.9.0")
-    def create_draft(self, title: Optional[str] = None, branch_name: Optional[str] = None) -> int:
-        """Create a draft.
-
-        Create a draft with the branch name. If the branch name is not given,
-        create a draft based on the branch name stored in the dataset client.
-        Then the dataset client will change the status to "draft"
-        and store the branch name and draft number.
-
-        Arguments:
-            title: The draft title.
-            branch_name: The branch name.
-
-        Returns:
-            The draft number of the created draft.
-
-        Raises:
-            StatusError: When creating the draft without basing on a branch.
-
-        """
-        if not branch_name:
-            if not self.status.branch_name:
-                raise StatusError(
-                    message="Creating the draft without basing on a branch is not allowed"
-                )
-            branch_name = self.status.branch_name
-            self._status.check_authority_for_commit()
-        draft_number = self._create_draft(title, branch_name)
-        self._status.checkout(draft_number=draft_number)
-        self._status.branch_name = branch_name
-        return draft_number
-
-    def get_draft(self, draft_number: Optional[int] = None) -> Draft:
-        """Get the certain draft with the given draft number.
-
-        Get the certain draft with the given draft number. If the draft number is not given,
-        get the draft based on the draft number stored in the dataset client.
-
-        Arguments:
-            draft_number: The required draft number.
-                If is not given, get the current draft.
-
-        Returns:
-            The :class:`.Draft` instance with the given number.
-
-        Raises:
-            TypeError: When the given draft number is illegal.
-            ResourceNotExistError: When the required draft does not exist.
-
-        """
-        if draft_number is None:
-            self._status.check_authority_for_draft()
-            draft_number = self._status.draft_number
-
-        if not draft_number:
-            raise TypeError("The given draft number is illegal")
-
-        for draft in self.list_drafts():
-            if draft_number == draft.number:
-                return draft
-
-        raise ResourceNotExistError(resource="draft", identification=draft_number)
-
-    def list_drafts(self) -> PagingList[Draft]:
-        """List all the drafts.
-
-        Returns:
-            The PagingList of :class:`drafts<.Draft>`.
-
-        """
-        return PagingList(self._generate_drafts, 128)
-
-    def get_commit(self, revision: Optional[str] = None) -> Commit:
-        """Get the certain commit with the given revision.
-
-        Get the certain commit with the given revision. If the revision is not given,
-        get the commit based on the commit id stored in the dataset client.
-
-        Arguments:
-            revision: The information to locate the specific commit, which can be the commit id,
-                the branch name, or the tag name.
-                If is not given, get the current commit.
-
-        Returns:
-            The :class:`.Commit` instance with the given revision.
-
-        Raises:
-            TypeError: When the given revision is illegal.
-            ResourceNotExistError: When the required commit does not exist.
-
-        """
-        if revision is None:
-            self._status.check_authority_for_commit()
-            revision = self._status.commit_id
-
-        if not revision:
-            raise TypeError("The given revision is illegal")
-
-        try:
-            commit = next(self._generate_commits(revision))
-        except StopIteration as error:
-            raise ResourceNotExistError(resource="commit", identification=revision) from error
-
-        return commit
-
-    def list_commits(self, revision: Optional[str] = None) -> PagingList[Commit]:
-        """List the commits.
-
-        Arguments:
-            revision: The information to locate the specific commit, which can be the commit id,
-                the branch name, or the tag name.
-                If is given, list the commits before the given commit.
-                If is not given, list the commits before the current commit.
-
-        Returns:
-            The PagingList of :class:`commits<.Commit>`.
-
-        """
-        return PagingList(
-            lambda offset, limit: self._generate_commits(revision, offset, limit), 128
-        )
-
-    def create_tag(self, name: str, revision: Optional[str] = None) -> None:
-        """Create a tag for a commit.
-
-        Create a tag for a commit with the given revision. If the revision is not given,
-        create a tag based on the commit id stored in the dataset client.
-
-        Arguments:
-            name: The tag name to be created for the specific commit.
-            revision: The information to locate the specific commit, which can be the commit id,
-                the branch name, or the tag name.
-                If the revision is not given, create the tag for the current commit.
-
-        """
-        if not revision:
-            self._status.check_authority_for_commit()
-            revision = self._status.commit_id
-
-        post_data: Dict[str, Any] = {"commit": revision, "name": name}
-
-        self._client.open_api_do("POST", "tags", self.dataset_id, json=post_data)
-
-    def get_tag(self, name: str) -> Tag:
-        """Get the certain tag with the given name.
-
-        Arguments:
-            name: The required tag name.
-
-        Returns:
-            The :class:`.Tag` instance with the given name.
-
-        Raises:
-            TypeError: When the given tag is illegal.
-            ResourceNotExistError: When the required tag does not exist.
-
-        """
-        if not name:
-            raise TypeError("The given tag name is illegal")
-
-        try:
-            tag = next(self._generate_tags(name))
-        except StopIteration as error:
-            raise ResourceNotExistError(resource="tag", identification=name) from error
-
-        return tag
-
-    def list_tags(self) -> PagingList[Tag]:
-        """List the information of tags.
-
-        Returns:
-            The PagingList of :class:`tags<.Tag>`.
-
-        """
-        return PagingList(lambda offset, limit: self._generate_tags(None, offset, limit), 128)
-
-    def create_branch(self, name: str, revision: Optional[str] = None) -> None:
-        """Create a branch.
-
-        Create a branch based on a commit with the given revision. If the revision is not given,
-        create a branch based on the commit id stored in the dataset client.
-        Then the dataset client will change the status to "commit"
-        and store the branch name and the commit id.
-
-        Arguments:
-            name: The branch name.
-            revision: The information to locate the specific commit, which can be the commit id,
-                the branch name, or the tag name.
-                If the revision is not given, create the branch based on the current commit.
-
-        """
-        if not revision:
-            self._status.check_authority_for_commit()
-        else:
-            self.checkout(revision=revision)
-        revision = self._status.commit_id
-
-        post_data: Dict[str, Any] = {"name": name, "commit": revision}
-        self._client.open_api_do("POST", "branches", self.dataset_id, json=post_data)
-
-        self._status.branch_name = name
-
-    def get_branch(self, name: str) -> Branch:
-        """Get the branch with the given name.
-
-        Arguments:
-            name: The required branch name.
-
-        Returns:
-            The :class:`.Branch` instance with the given name.
-
-        Raises:
-            TypeError: When the given branch is illegal.
-            ResourceNotExistError: When the required branch does not exist.
-
-        """
-        if not name:
-            raise TypeError("The given branch name is illegal")
-
-        try:
-            branch = next(self._generate_branches(name))
-        except StopIteration as error:
-            raise ResourceNotExistError(resource="branch", identification=name) from error
-
-        return branch
-
-    def list_branches(self) -> PagingList[Branch]:
-        """List the information of branches.
-
-        Returns:
-            The PagingList of :class:`branches<.Branch>`.
-
-        """
-        return PagingList(lambda offset, limit: self._generate_branches(None, offset, limit), 128)
-
-    def delete_branch(self, name: str) -> None:
-        """Delete a branch.
-
-        Delete the branch with the given branch name. Note that deleting the branch with the name
-        which is stored in the current dataset client is not allowed.
-
-        Arguments:
-            name: The name of the branch to be deleted.
-
-        Raises:
-            OperationError: When deleting the current branch.
-
-        """
-        if name == self.status.branch_name:
-            raise OperationError("Deleting the current branch is not allowed")
-
-        self._delete_branch(name)
-
-    def checkout(self, revision: Optional[str] = None, draft_number: Optional[int] = None) -> None:
-        """Checkout to commit or draft.
-
-        Arguments:
-            revision: The information to locate the specific commit, which can be the commit id,
-                the branch, or the tag.
-            draft_number: The draft number.
-
-        Raises:
-            TypeError: When both commit and draft number are provided or neither.
-
-        """
-        if revision is None and draft_number is None:
-            raise TypeError("Neither revision nor draft number is given, please give one")
-        if revision is not None and draft_number is not None:
-            raise TypeError("Both revision and draft number are given, please only give one")
-
-        if revision:
-            try:
-                branch = self.get_branch(revision)
-                self._status.checkout(commit_id=branch.commit_id)
-                self._status.branch_name = branch.name
-            except ResourceNotExistError:
-                self._status.checkout(commit_id=self.get_commit(revision).commit_id)
-                self._status.branch_name = None
-
-        if draft_number:
-            draft = self.get_draft(draft_number)
-            self._status.checkout(draft_number=draft.number)
-            self._status.branch_name = draft.branch_name
-
-    def commit(self, title: str, description: str = "", *, tag: Optional[str] = None) -> None:
-        """Commit the draft.
-
-        Commit the draft based on the draft number stored in the dataset client.
-        Then the dataset client will change the status to "commit"
-        and store the branch name and commit id.
-
-        Arguments:
-            title: The commit title.
-            description: The commit description.
-            tag: A tag for current commit.
-
-        """
-        self._status.check_authority_for_draft()
-        self._status.checkout(commit_id=self._commit(title, description, tag))
-
     def update_notes(
         self,
         *,
@@ -545,7 +163,7 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
 
         patch_data.update(self._status.get_status_info())
 
-        self._client.open_api_do("PATCH", "notes", self.dataset_id, json=patch_data)
+        self._client.open_api_do("PATCH", "notes", self._dataset_id, json=patch_data)
 
     def get_notes(self) -> Notes:
         """Get the notes.
@@ -557,7 +175,7 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
         params: Dict[str, Any] = self._status.get_status_info()
 
         return Notes.loads(
-            self._client.open_api_do("GET", "notes", self.dataset_id, params=params).json()
+            self._client.open_api_do("GET", "notes", self._dataset_id, params=params).json()
         )
 
     def list_segment_names(self) -> PagingList[str]:
@@ -579,7 +197,7 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
         params: Dict[str, Any] = self._status.get_status_info()
 
         response = self._client.open_api_do(
-            "GET", "labels/catalogs", self.dataset_id, params=params
+            "GET", "labels/catalogs", self._dataset_id, params=params
         ).json()
         return Catalog.loads(response["catalog"])
 
@@ -600,18 +218,7 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
             raise TypeError("Empty catalog")
         put_data.update(self._status.get_status_info())
 
-        self._client.open_api_do("PUT", "labels/catalogs", self.dataset_id, json=put_data)
-
-    def delete_tag(self, name: str) -> None:
-        """Delete a tag.
-
-        Arguments:
-            name: The tag name to be deleted for the specific commit.
-
-        """
-        delete_data: Dict[str, Any] = {"name": name}
-
-        self._client.open_api_do("DELETE", "tags", self.dataset_id, json=delete_data)
+        self._client.open_api_do("PUT", "labels/catalogs", self._dataset_id, json=put_data)
 
     def delete_segment(self, name: str) -> None:
         """Delete a segment of the draft.
@@ -625,7 +232,7 @@ class DatasetClientBase:  # pylint: disable=too-many-public-methods
         delete_data: Dict[str, Any] = {"segmentName": name}
         delete_data.update(self._status.get_status_info())
 
-        self._client.open_api_do("DELETE", "segments", self.dataset_id, json=delete_data)
+        self._client.open_api_do("DELETE", "segments", self._dataset_id, json=delete_data)
 
 
 class DatasetClient(DatasetClientBase):
@@ -666,21 +273,27 @@ class DatasetClient(DatasetClientBase):
         pbar: Tqdm,
     ) -> SegmentClient:
         segment_client = self.get_or_create_segment(segment.name)
-        local_data: Iterator[Data] = filter(
-            lambda data: pbar.update_for_skip(isinstance(data, Data)),
+        all_data: Iterator[Union[AuthData, Data]] = filter(
+            lambda data: pbar.update_for_skip(not isinstance(data, RemoteData)),
             segment,  # type: ignore[arg-type]
         )
         if skip_uploaded_files:
             done_set = set(segment_client.list_data_paths())
             segment_filter = filter(
                 lambda data: pbar.update_for_skip(data.target_remote_path not in done_set),
-                local_data,
+                all_data,
             )
         else:
-            segment_filter = local_data
-
-        multithread_upload(segment_client.upload_data, segment_filter, jobs=jobs, pbar=pbar)
+            segment_filter = all_data
 
+        multithread_upload(
+            # pylint: disable=protected-access
+            segment_client._upload_or_import_data,
+            segment_filter,
+            callback=segment_client._synchronize_upload_info,
+            jobs=jobs,
+            pbar=pbar,
+        )
         return segment_client
 
     def get_or_create_segment(self, name: str = "default") -> SegmentClient:
@@ -718,6 +331,79 @@ class DatasetClient(DatasetClientBase):
             raise NameConflictError(resource="segment", identification=name)
         return SegmentClient(name, self)
 
+    def copy_segment(
+        self,
+        source_name: str,
+        target_name: Optional[str] = None,
+        *,
+        source_client: Optional["DatasetClient"] = None,
+        strategy: str = "abort",
+    ) -> SegmentClient:
+        """Copy segment to this dataset.
+
+        Arguments:
+            source_name: The source name of the copied segment.
+            target_name: The target name of the copied segment.
+                This argument is used to specify a new name of the copied segment.
+                If None, the name of the copied segment will not be changed after copy.
+            source_client: The source dataset client of the copied segment.
+                This argument is used to specify where the copied segment comes from when the
+                copied segment is from another commit, draft or even another dataset.
+                If None, the copied segment comes from this dataset.
+            strategy: The strategy of handling the name conflict. There are three options:
+
+                1. "abort": stop copying and raise exception;
+                2. "override": the source segment will override the origin segment;
+                3. "skip": keep the origin segment.
+
+        Returns:
+            The client of the copied target segment.
+
+        """
+        if not target_name:
+            target_name = source_name
+        self._copy_segment(source_name, target_name, source_client=source_client, strategy=strategy)
+
+        return SegmentClient(target_name, self)
+
+    def move_segment(
+        self,
+        source_name: str,
+        target_name: str,
+        *,
+        strategy: str = "abort",
+    ) -> SegmentClient:
+        """Move/Rename segment in this dataset.
+
+        Arguments:
+            source_name: The source name of the moved segment.
+            target_name: The target name of the moved segment.
+            strategy: The strategy of handling the name conflict. There are three options:
+
+                1. "abort": stop moving and raise exception;
+                2. "override": the source segment will override the origin segment;
+                3. "skip": keep the origin segment.
+
+        Returns:
+            The client of the moved target segment.
+
+        Raises:
+            InvalidParamsError: When the strategy is invalid.
+
+        """
+        self._status.check_authority_for_draft()
+        if strategy not in _STRATEGIES:
+            raise InvalidParamsError(param_name="strategy", param_value=strategy)
+        post_data: Dict[str, Any] = {
+            "strategy": strategy,
+            "source": {"segmentName": source_name},
+            "segmentName": target_name,
+        }
+        post_data.update(self._status.get_status_info())
+
+        self._client.open_api_do("POST", "segments?move", self._dataset_id, json=post_data)
+        return SegmentClient(target_name, self)
+
     def get_segment(self, name: str = "default") -> SegmentClient:
         """Get a segment in a certain commit according to given name.
 
@@ -771,7 +457,10 @@ class DatasetClient(DatasetClientBase):
         try:
             with Tqdm(len(segment), disable=quiet) as pbar:
                 return self._upload_segment(
-                    segment, jobs=jobs, skip_uploaded_files=skip_uploaded_files, pbar=pbar
+                    segment,
+                    jobs=jobs,
+                    skip_uploaded_files=skip_uploaded_files,
+                    pbar=pbar,
                 )
         except Exception:
             logger.error(
@@ -839,7 +528,7 @@ class FusionDatasetClient(DatasetClientBase):
         pbar: Tqdm,
     ) -> FusionSegmentClient:
         segment_client = self.get_or_create_segment(segment.name)
-        for sensor in segment.sensors.values():
+        for sensor in segment.sensors:
             segment_client.upload_sensor(sensor)
 
         segment_filter: Iterator[Tuple[Frame, Optional[float], bool]]
@@ -913,6 +602,79 @@ class FusionDatasetClient(DatasetClientBase):
             raise NameConflictError(resource="segment", identification=name)
         return FusionSegmentClient(name, self)
 
+    def copy_segment(
+        self,
+        source_name: str,
+        target_name: Optional[str] = None,
+        *,
+        source_client: Optional["FusionDatasetClient"] = None,
+        strategy: str = "abort",
+    ) -> FusionSegmentClient:
+        """Copy segment to this dataset.
+
+        Arguments:
+            source_name: The source name of the copied segment.
+            target_name: The target name of the copied segment.
+                This argument is used to specify a new name of the copied segment.
+                If None, the name of the copied segment will not be changed after copy.
+            source_client: The source dataset client of the copied segment.
+                This argument is used to specify where the copied segment comes from when the
+                copied segment is from another commit, draft or even another dataset.
+                If None, the copied segment comes from this dataset.
+            strategy: The strategy of handling the name conflict. There are three options:
+
+                1. "abort": stop copying and raise exception;
+                2. "override": the source segment will override the origin segment;
+                3. "skip": keep the origin segment.
+
+        Returns:
+            The client of the copied target segment.
+
+        """
+        if not target_name:
+            target_name = source_name
+        self._copy_segment(source_name, target_name, source_client=source_client, strategy=strategy)
+
+        return FusionSegmentClient(target_name, self)
+
+    def move_segment(
+        self,
+        source_name: str,
+        target_name: str,
+        *,
+        strategy: str = "abort",
+    ) -> FusionSegmentClient:
+        """Move/Rename segment in this dataset.
+
+        Arguments:
+            source_name: The source name of the moved segment.
+            target_name: The target name of the moved segment.
+            strategy: The strategy of handling the name conflict. There are three options:
+
+                1. "abort": stop moving and raise exception;
+                2. "override": the source segment will override the origin segment;
+                3. "skip": keep the origin segment.
+
+        Returns:
+            The client of the moved target segment.
+
+        Raises:
+            InvalidParamsError: When the strategy is invalid.
+
+        """
+        self._status.check_authority_for_draft()
+        if strategy not in _STRATEGIES:
+            raise InvalidParamsError(param_name="strategy", param_value=strategy)
+        post_data: Dict[str, Any] = {
+            "strategy": strategy,
+            "source": {"segmentName": source_name},
+            "segmentName": target_name,
+        }
+        post_data.update(self._status.get_status_info())
+
+        self._client.open_api_do("POST", "segments?move", self._dataset_id, json=post_data)
+        return FusionSegmentClient(target_name, self)
+
     def get_segment(self, name: str = "default") -> FusionSegmentClient:
         """Get a fusion segment in a certain commit according to given name.
 
