@@ -28,22 +28,25 @@ import time
 from copy import deepcopy
 from hashlib import sha1
 from itertools import islice
-from typing import TYPE_CHECKING, Any, Dict, Generator, Iterable, Optional, Union
+from typing import TYPE_CHECKING, Any, Dict, Generator, Iterable, List, Optional, Union
 
 import filetype
 from requests_toolbelt import MultipartEncoder
 from ulid import from_timestamp
 
-from ..dataset import Data, Frame, RemoteData
-from ..exception import FrameError, InvalidParamsError, ResponseSystemError
+from ..dataset import AuthData, Data, Frame, RemoteData
+from ..exception import FrameError, InvalidParamsError, OperationError, ResponseSystemError
 from ..sensor.sensor import Sensor, Sensors
 from ..utility import Disable, locked
-from .requests import PagingList, config
+from .lazy import PagingList
+from .requests import config
 from .status import Status
 
 if TYPE_CHECKING:
     from .dataset import DatasetClient, FusionDatasetClient
 
+_STRATEGIES = {"abort", "override", "skip"}
+
 
 class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
     """This class defines the basic concept of :class:`SegmentClient`.
@@ -97,6 +100,20 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
         response = self._client.open_api_do("GET", "data/urls", self._dataset_id, params=params)
         return response.json()["urls"][0]["url"]  # type: ignore[no-any-return]
 
+    def _list_urls(self, offset: int = 0, limit: int = 128) -> Dict[str, Any]:
+        params: Dict[str, Any] = {
+            "segmentName": self._name,
+            "offset": offset,
+            "limit": limit,
+        }
+        params.update(self._status.get_status_info())
+
+        if config.is_internal:
+            params["isInternal"] = True
+
+        response = self._client.open_api_do("GET", "data/urls", self._dataset_id, params=params)
+        return response.json()  # type: ignore[no-any-return]
+
     def _list_labels(self, offset: int = 0, limit: int = 128) -> Dict[str, Any]:
         params: Dict[str, Any] = {
             "segmentName": self._name,
@@ -171,29 +188,38 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
             }
             self._client.do("PUT", url, data=fp, headers=request_headers)
 
-    def _synchronize_upload_info(  # pylint: disable=too-many-arguments
+    def _synchronize_upload_info(
         self,
-        remote_path: str,
-        checksum: str,
-        frame_info: Optional[Dict[str, Any]] = None,
+        callback_info: List[Dict[str, Any]],
         skip_uploaded_files: bool = False,
     ) -> None:
         put_data: Dict[str, Any] = {
             "segmentName": self.name,
-            "objects": [{"checksum": checksum, "remotePath": remote_path}],
+            "objects": callback_info,
         }
         put_data.update(self._status.get_status_info())
 
-        if frame_info:
-            put_data["objects"][0].update(frame_info)
-
         try:
             self._client.open_api_do("PUT", "multi/callback", self._dataset_id, json=put_data)
         except ResponseSystemError:
             if not skip_uploaded_files:
                 raise
 
-    def _upload_label(self, data: Data) -> None:
+    def _import_cloud_file(
+        self,
+        cloud_path: str,
+        remote_path: str,
+    ) -> None:
+
+        put_data: Dict[str, Any] = {
+            "segmentName": self.name,
+            "objects": [{"cloudPath": cloud_path, "remotePath": remote_path}],
+            "deleteSource": False,
+        }
+        put_data.update(self._status.get_status_info())
+        self._client.open_api_do("PUT", "multi/cloud-callback", self._dataset_id, json=put_data)
+
+    def _upload_label(self, data: Union[AuthData, Data]) -> None:
         label = data.label.dumps()
         if not label:
             return
@@ -227,7 +253,7 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
         """
         return self._status
 
-    @Disable(since="v1.6.0", enabled_in="v1.7.0", reason="TensorBay server refactor")
+    @Disable(since="v1.6.0", enabled_in="v1.9.0", reason="TensorBay server refactor")
     def delete_data(self, remote_paths: Union[str, Iterable[str]]) -> None:
         """Delete data of a segment in a certain commit with the given remote paths.
 
@@ -281,29 +307,50 @@ class SegmentClient(SegmentClientBase):
 
         return response["totalCount"]  # type: ignore[no-any-return]
 
-    def _generate_data(self, offset: int = 0, limit: int = 128) -> Generator[RemoteData, None, int]:
+    def _generate_data(
+        self, urls: PagingList[str], offset: int = 0, limit: int = 128
+    ) -> Generator[RemoteData, None, int]:
         response = self._list_labels(offset, limit)
 
-        for item in response["labels"]:
+        for i, item in enumerate(response["labels"], offset):
             data = RemoteData.loads(item)
-            data._url_getter = self._get_url  # pylint: disable=protected-access
+            # pylint: disable=protected-access
+            data._url_getter = lambda _, i=i: urls[i]  # type: ignore[misc]
             yield data
 
         return response["totalCount"]  # type: ignore[no-any-return]
 
-    def upload_file(self, local_path: str, target_remote_path: str = "") -> None:
+    def _generate_urls(self, offset: int = 0, limit: int = 128) -> Generator[str, None, int]:
+        response = self._list_urls(offset, limit)
+
+        for item in response["urls"]:
+            yield item["url"]
+
+        return response["totalCount"]  # type: ignore[no-any-return]
+
+    def _upload_or_import_data(self, data: Union[Data, AuthData]) -> Optional[Dict[str, Any]]:
+        if isinstance(data, Data):
+            callback_info = self._upload_file(data.path, data.target_remote_path)
+            if data.label:
+                callback_info["label"] = data.label.dumps()
+            return callback_info
+        self.import_auth_data(data)
+        return None
+
+    def _upload_file(self, local_path: str, target_remote_path: str = "") -> Dict[str, Any]:
         """Upload data with local path to the draft.
 
         Arguments:
             local_path: The local path of the data to upload.
             target_remote_path: The path to save the data in segment client.
 
+        Returns:
+            The sha1 and target remote path of the file.
+
         Raises:
             InvalidParamsError: When target_remote_path does not follow linux style.
 
         """
-        self._status.check_authority_for_draft()
-
         if not target_remote_path:
             target_remote_path = os.path.basename(local_path)
 
@@ -314,14 +361,13 @@ class SegmentClient(SegmentClientBase):
         post_data = permission["result"]
 
         checksum = self._calculate_file_sha1(local_path)
-
-        post_data["key"] = checksum
+        post_data["key"] = permission["extra"]["objectPrefix"] + checksum
 
         backend_type = permission["extra"]["backendType"]
         if backend_type == "azure":
             url = (
                 f'{permission["extra"]["host"]}{permission["extra"]["objectPrefix"]}'
-                f'{target_remote_path}?{permission["result"]["token"]}'
+                f'{checksum}?{permission["result"]["token"]}'
             )
 
             self._put_binary_file_to_azure(url, local_path, post_data)
@@ -333,7 +379,21 @@ class SegmentClient(SegmentClientBase):
                 post_data,
             )
 
-        self._synchronize_upload_info(target_remote_path, checksum)
+        return {"checksum": checksum, "remotePath": target_remote_path}
+
+    def upload_file(self, local_path: str, target_remote_path: str = "") -> None:
+        """Upload data with local path to the draft.
+
+        Arguments:
+            local_path: The local path of the data to upload.
+            target_remote_path: The path to save the data in segment client.
+
+        """
+        self._status.check_authority_for_draft()
+
+        callback_info = self._upload_file(local_path, target_remote_path)
+
+        self._synchronize_upload_info([callback_info])
 
     def upload_label(self, data: Data) -> None:
         """Upload label with Data object to the draft.
@@ -355,9 +415,196 @@ class SegmentClient(SegmentClientBase):
         """
         self._status.check_authority_for_draft()
 
-        self.upload_file(data.path, data.target_remote_path)
+        callback_info = self._upload_file(data.path, data.target_remote_path)
+        if data.label:
+            callback_info["label"] = data.label.dumps()
+        self._synchronize_upload_info([callback_info])
+
+    def import_auth_data(self, data: AuthData) -> None:
+        """Import AuthData object to the draft.
+
+        Arguments:
+            data: The :class:`~tensorbay.dataset.data.Data`.
+
+        """
+        self._status.check_authority_for_draft()
+
+        self._import_cloud_file(data.path, data.target_remote_path)
         self._upload_label(data)
 
+    def copy_data(
+        self,
+        source_remote_paths: Union[str, Iterable[str]],
+        target_remote_paths: Union[None, str, Iterable[str]] = None,
+        *,
+        source_client: Optional["SegmentClient"] = None,
+        strategy: str = "abort",
+    ) -> None:
+        """Copy data to this segment.
+
+        Arguments:
+            source_remote_paths: The source remote paths of the copied data.
+            target_remote_paths: The target remote paths of the copied data.
+                This argument is used to specify new remote paths of the copied data.
+                If None, the remote path of the copied data will not be changed after copy.
+            source_client: The source segment client of the copied data.
+                This argument is used to specifies where the copied data comes from when the copied
+                data is from another commit, draft, segment or even another dataset.
+                If None, the copied data comes from this segment.
+            strategy: The strategy of handling the name conflict. There are three options:
+
+                1. "abort": stop copying and raise exception;
+                2. "override": the source data will override the origin data;
+                3. "skip": keep the origin data.
+
+        Raises:
+            InvalidParamsError: When strategy is invalid.
+            OperationError: When the type of target_remote_paths is not equal
+                with source_remote_paths.
+
+        """
+        self._status.check_authority_for_draft()
+
+        if strategy not in _STRATEGIES:
+            raise InvalidParamsError(param_name="strategy", param_value=strategy)
+
+        if not target_remote_paths:
+            all_target_remote_paths = []
+            all_source_remote_paths = (
+                [source_remote_paths]
+                if isinstance(source_remote_paths, str)
+                else list(source_remote_paths)
+            )
+
+        elif isinstance(source_remote_paths, str) and isinstance(target_remote_paths, str):
+            all_target_remote_paths = [target_remote_paths]
+            all_source_remote_paths = [source_remote_paths]
+
+        elif not isinstance(source_remote_paths, str) and not isinstance(target_remote_paths, str):
+            all_target_remote_paths = list(target_remote_paths)
+            all_source_remote_paths = list(source_remote_paths)
+            if len(all_target_remote_paths) != len(all_source_remote_paths):
+                raise OperationError(
+                    "To copy the data, the length of target_remote_paths "
+                    "must be equal with source_remote_paths"
+                )
+        else:
+            raise OperationError(
+                "To copy the data, the type of target_remote_paths "
+                "must be equal with source_remote_paths"
+            )
+
+        source = {}
+        if source_client:
+            source["segmentName"] = source_client.name
+            source["id"] = source_client._dataset_id  # pylint: disable=protected-access
+            source.update(source_client.status.get_status_info())
+        else:
+            source["segmentName"] = self.name
+
+        post_data: Dict[str, Any] = {
+            "strategy": strategy,
+            "source": source,
+            "segmentName": self.name,
+        }
+        post_data.update(self._status.get_status_info())
+
+        for start in range(0, len(all_source_remote_paths), 128):
+            request_target_remote_paths = all_target_remote_paths[start : start + 128]
+            request_source_remote_paths = all_source_remote_paths[start : start + 128]
+
+            if request_target_remote_paths:
+                post_data["remotePaths"] = request_target_remote_paths
+            post_data["source"]["remotePaths"] = request_source_remote_paths
+
+            self._client.open_api_do("POST", "data?multipleCopy", self._dataset_id, json=post_data)
+
+    def move_data(
+        self,
+        source_remote_paths: Union[str, Iterable[str]],
+        target_remote_paths: Union[None, str, Iterable[str]] = None,
+        *,
+        source_client: Optional["SegmentClient"] = None,
+    ) -> None:
+        """Move data to this segment, also used to rename data.
+
+        Arguments:
+            source_remote_paths: The source remote paths of the moved data.
+            target_remote_paths: The target remote paths of the moved data.
+                This argument is used to specify new remote paths of the moved data.
+                If None, the remote path of the moved data will not be changed after copy.
+            source_client: The source segment client of the moved data.
+                This argument is used to specifies where the moved data comes from when the moved
+                data is from another segment.
+                If None, the moved data comes from this segment.
+
+        Raises:
+            OperationError: When the type or the length of target_remote_paths is not equal
+                with source_remote_paths.
+                Or when the dataset_id and drafter_number of source_client
+                is not equal with the current segment client.
+
+        """
+        self._status.check_authority_for_draft()
+
+        if not target_remote_paths:
+            all_target_remote_paths = []
+            all_source_remote_paths = (
+                [source_remote_paths]
+                if isinstance(source_remote_paths, str)
+                else list(source_remote_paths)
+            )
+
+        elif isinstance(source_remote_paths, str) and isinstance(target_remote_paths, str):
+            all_target_remote_paths = [target_remote_paths]
+            all_source_remote_paths = [source_remote_paths]
+
+        elif not isinstance(source_remote_paths, str) and not isinstance(target_remote_paths, str):
+            all_target_remote_paths = list(target_remote_paths)
+            all_source_remote_paths = list(source_remote_paths)
+            if len(all_target_remote_paths) != len(all_source_remote_paths):
+                raise OperationError(
+                    "To move the data, the length of target_remote_paths "
+                    "must be equal with source_remote_paths"
+                )
+        else:
+            raise OperationError(
+                "To move the data, the type of target_remote_paths "
+                "must be equal with source_remote_paths"
+            )
+
+        source = {}
+        if source_client:
+            if (
+                source_client.status.draft_number == self.status.draft_number
+                and source_client._dataset_id  # pylint: disable=protected-access
+                == self._dataset_id  # pylint: disable=protected-access
+            ):
+                source["segmentName"] = source_client.name
+            else:
+                raise OperationError(
+                    "To move the data, the dataset_id and drafter_number of source_client "
+                    "must be equal with the current segment client"
+                )
+        else:
+            source["segmentName"] = self.name
+
+        post_data: Dict[str, Any] = {
+            "source": source,
+            "segmentName": self.name,
+        }
+        post_data.update(self._status.get_status_info())
+
+        for start in range(0, len(all_source_remote_paths), 128):
+            request_target_remote_paths = all_target_remote_paths[start : start + 128]
+            request_source_remote_paths = all_source_remote_paths[start : start + 128]
+
+            if request_target_remote_paths:
+                post_data["remotePaths"] = request_target_remote_paths
+            post_data["source"]["remotePaths"] = request_source_remote_paths
+
+            self._client.open_api_do("POST", "data?multipleMove", self._dataset_id, json=post_data)
+
     def list_data_paths(self) -> PagingList[str]:
         """List required data path in a segment in a certain commit.
 
@@ -374,7 +621,17 @@ class SegmentClient(SegmentClientBase):
             The PagingList of :class:`~tensorbay.dataset.data.RemoteData`.
 
         """
-        return PagingList(self._generate_data, 128)
+        urls = self.list_urls()
+        return PagingList(lambda offset, limit: self._generate_data(urls, offset, limit), 128)
+
+    def list_urls(self) -> PagingList[str]:
+        """List the data urls in this segment.
+
+        Returns:
+            The PagingList of urls.
+
+        """
+        return PagingList(self._generate_urls, 128)
 
 
 class FusionSegmentClient(SegmentClientBase):
@@ -395,18 +652,32 @@ class FusionSegmentClient(SegmentClientBase):
     def __init__(self, name: str, data_client: "FusionDatasetClient") -> None:
         super().__init__(name, data_client)
 
-    def _generate_frames(self, offset: int = 0, limit: int = 128) -> Generator[Frame, None, int]:
+    def _generate_frames(
+        self, urls: PagingList[Dict[str, str]], offset: int = 0, limit: int = 128
+    ) -> Generator[Frame, None, int]:
         response = self._list_labels(offset, limit)
 
-        for item in response["labels"]:
+        data: RemoteData
+        for i, item in enumerate(response["labels"], offset):
             frame = Frame.loads(item)
-            for data in frame.values():  # pylint: disable=no-member # pylint issue: #3131
+            # pylint: disable=no-member # pylint issue: #3131
+            for sensor_name, data in frame.items():  # type: ignore[assignment]
                 # pylint: disable=protected-access
-                data._url_getter = self._get_url  # type: ignore[union-attr]
+                data._url_getter = lambda _, i=i, s=sensor_name: urls[i][s]  # type: ignore[misc]
             yield frame
 
         return response["totalCount"]  # type: ignore[no-any-return]
 
+    def _generate_urls(
+        self, offset: int = 0, limit: int = 128
+    ) -> Generator[Dict[str, str], None, int]:
+        response = self._list_urls(offset, limit)
+
+        for frame in response["urls"]:
+            yield {item["sensorName"]: item["url"] for item in frame["urls"]}
+
+        return response["totalCount"]  # type: ignore[no-any-return]
+
     def get_sensors(self) -> Sensors:
         """Return the sensors in a fusion segment client.
 
@@ -495,14 +766,13 @@ class FusionSegmentClient(SegmentClientBase):
             post_data = permission["result"]
 
             checksum = self._calculate_file_sha1(data.path)
-
-            post_data["key"] = checksum
+            post_data["key"] = permission["extra"]["objectPrefix"] + checksum
 
             backend_type = permission["extra"]["backendType"]
             if backend_type == "azure":
                 url = (
                     f'{permission["extra"]["host"]}{permission["extra"]["objectPrefix"]}'
-                    f'{target_remote_path}?{permission["result"]["token"]}'
+                    f'{checksum}?{permission["result"]["token"]}'
                 )
 
                 self._put_binary_file_to_azure(url, data.path, post_data)
@@ -515,18 +785,19 @@ class FusionSegmentClient(SegmentClientBase):
                 )
 
             frame_info: Dict[str, Any] = {
-                "segmentName": self._name,
                 "sensorName": sensor_name,
                 "frameId": str(frame_id),
             }
             if hasattr(data, "timestamp"):
                 frame_info["timestamp"] = data.timestamp
 
-            self._synchronize_upload_info(
-                target_remote_path, checksum, frame_info, skip_uploaded_files
-            )
-
-            self._upload_label(data)
+            callback_info = {
+                "checksum": checksum,
+                "remotePath": target_remote_path,
+                "label": data.label.dumps(),
+            }
+            callback_info.update(frame_info)
+            self._synchronize_upload_info([callback_info], skip_uploaded_files)
 
     def list_frames(self) -> PagingList[Frame]:
         """List required frames in the segment in a certain commit.
@@ -535,4 +806,16 @@ class FusionSegmentClient(SegmentClientBase):
             The PagingList of :class:`~tensorbay.dataset.frame.Frame`.
 
         """
-        return PagingList(self._generate_frames, 128)
+        urls = self.list_urls()
+        return PagingList(lambda offset, limit: self._generate_frames(urls, offset, limit), 128)
+
+    def list_urls(self) -> PagingList[Dict[str, str]]:
+        """List the data urls in this segment.
+
+        Returns:
+            The PagingList of url dict, which key is the sensor name, value is the url.
+
+        """
+        urls = PagingList(self._generate_urls, 128)
+        urls._repr_maxlevel = 2  # pylint: disable=protected-access
+        return urls
