@@ -14,8 +14,8 @@ import os
 from http.client import HTTPResponse
 from string import printable
 from typing import Any, Callable, Dict, Optional, Type, TypeVar, Union
-from urllib.parse import quote
-from urllib.request import urlopen
+from urllib.parse import quote, urljoin
+from urllib.request import pathname2url, urlopen
 
 from _io import BufferedReader
 
@@ -33,12 +33,13 @@ class DataBase(AttrsMixin, ReprMixin):  # pylint: disable=too-few-public-methods
     Attributes:
         path: The file path.
         timestamp: The timestamp for the file.
-        labels: The :class:`Labels` that contains all the label information of the file.
+        label: The :class:`~tensorbay.label.label.Label` instance that contains
+            all the label information of the file.
 
     """
 
     _T = TypeVar("_T", bound="DataBase")
-    _Type = Union["Data", "RemoteData"]
+    _Type = Union["Data", "RemoteData", "AuthData"]
 
     _repr_type = ReprType.INSTANCE
     _repr_attrs = ("timestamp", "label")
@@ -61,13 +62,13 @@ class DataBase(AttrsMixin, ReprMixin):  # pylint: disable=too-few-public-methods
 
     @staticmethod
     def loads(contents: Dict[str, Any]) -> "_Type":
-        """Loads :class:`Data` or :class:`RemoteData` from a dict containing data information.
+        """Loads data subclass from a dict containing data information.
 
         Arguments:
             contents: A dict containing the information of the data, which looks like::
 
                     {
-                        "localPath" or "remotePath": <str>,
+                        "localPath", "remotePath" or "authPath": <str>,
                         "timestamp": <float>,
                         "label": {
                             "CLASSIFICATION": {...},
@@ -81,11 +82,17 @@ class DataBase(AttrsMixin, ReprMixin):  # pylint: disable=too-few-public-methods
                     }
 
         Returns:
-            A :class:`Data` or :class:`RemoteData` instance containing the given dict information.
+            A :class:`Data`, :class:`RemoteData` or class`AuthData` instance containing
+            information from the given dict.
+
+        Raises:
+            KeyError: When the "localPath", "remotePath" or "authPath" not in contents.
 
         """
-        cls = Data if Data._PATH_KEY in contents else RemoteData  # pylint: disable=protected-access
-        return common_loads(cls, contents)
+        for key, value in _DATA_SUBCLASS:
+            if key in contents:
+                return common_loads(value, contents)
+        raise KeyError("Must contain 'localPath', 'remotePath' or 'authPath' in contents.")
 
 
 class Data(DataBase):
@@ -104,7 +111,8 @@ class Data(DataBase):
     Attributes:
         path: The file local path.
         timestamp: The timestamp for the file.
-        labels: The :class:`Labels` that contains all the label information of the file.
+        label: The :class:`~tensorbay.label.label.Label` instance that contains
+                all the label information of the file.
         target_remote_path: The target remote path of the data.
 
     """
@@ -205,6 +213,15 @@ class Data(DataBase):
         """
         return super()._dumps()
 
+    def get_url(self) -> str:
+        """Return the url of the local data file.
+
+        Returns:
+            The url of the local data.
+
+        """
+        return urljoin("file:", pathname2url(os.path.abspath(self.path)))
+
 
 class RemoteData(DataBase):
     """RemoteData is a combination of a specific tensorbay dataset file and its label.
@@ -222,7 +239,8 @@ class RemoteData(DataBase):
     Attributes:
         path: The file remote path.
         timestamp: The timestamp for the file.
-        labels: The :class:`Labels` that contains all the label information of the file.
+        label: The :class:`~tensorbay.label.label.Label` instance that contains
+                all the label information of the file.
 
     """
 
@@ -318,3 +336,142 @@ class RemoteData(DataBase):
 
         """
         return super()._dumps()
+
+
+class AuthData(DataBase):
+    """AuthData is a combination of a specific cloud storaged file and its label.
+
+    It contains the cloud storage file path, label information of the file
+    and the file metadata, such as timestamp.
+
+    An AuthData instance contains one or several types of labels.
+
+    Arguments:
+        cloud_path: The cloud file path.
+        target_remote_path: The file remote path after uploading to tensorbay.
+        timestamp: The timestamp for the file.
+        url_getter: The url getter of the remote file.
+
+    Attributes:
+        path: The cloud file path.
+        timestamp: The timestamp for the file.
+        label: The :class:`~tensorbay.label.label.Label` instance that contains
+                all the label information of the file.
+
+    """
+
+    _T = TypeVar("_T", bound="AuthData")
+
+    _PATH_KEY = "cloudPath"
+    path: str = attr(key=_PATH_KEY)
+
+    def __init__(
+        self,
+        cloud_path: str,
+        *,
+        target_remote_path: Optional[str] = None,
+        timestamp: Optional[float] = None,
+        url_getter: Optional[Callable[[str], str]] = None,
+    ) -> None:
+        super().__init__(cloud_path, timestamp=timestamp)
+        self._target_remote_path = target_remote_path
+        self._url_getter = url_getter
+
+    @classmethod
+    def loads(cls: Type[_T], contents: Dict[str, Any]) -> _T:
+        """Loads :class:`AuthData` from a dict containing remote data information.
+
+        Arguments:
+            contents: A dict containing the information of the data, which looks like::
+
+                    {
+                        "cloudPath": <str>,
+                        "timestamp": <float>,
+                        "label": {
+                            "CLASSIFICATION": {...},
+                            "BOX2D": {...},
+                            "BOX3D": {...},
+                            "POLYGON2D": {...},
+                            "POLYLINE2D": {...},
+                            "KEYPOINTS2D": {...},
+                            "SENTENCE": {...}
+                        }
+                    }
+
+        Returns:
+            An :class:`AuthData` instance containing information from the given dict.
+
+        """
+        return common_loads(cls, contents)
+
+    def dumps(self) -> Dict[str, Any]:
+        """Dumps the auth data into a dict.
+
+        Returns:
+            Dumped data dict, which looks like::
+
+                    {
+                        "cloudPath": <str>,
+                        "timestamp": <float>,
+                        "label": {
+                            "CLASSIFICATION": {...},
+                            "BOX2D": {...},
+                            "BOX3D": {...},
+                            "POLYGON2D": {...},
+                            "POLYLINE2D": {...},
+                            "KEYPOINTS2D": {...},
+                            "SENTENCE": {...}
+                        }
+                    }
+
+        """
+        return super()._dumps()
+
+    @property
+    def target_remote_path(self) -> str:
+        """Return the target remote path of the auth data.
+
+        Target remote path will be used when this data is uploaded to tensorbay, and the target
+        remote path will be the uploaded file's remote path.
+
+        Returns:
+            The target remote path of the auth data.
+
+        """
+        if not self._target_remote_path:
+            self._target_remote_path = self.path.split("/")[-1]
+
+        return self._target_remote_path
+
+    @target_remote_path.setter
+    def target_remote_path(self, target_remote_path: str) -> None:
+        self._target_remote_path = target_remote_path
+
+    def get_url(self) -> str:
+        """Return the url of the auth data.
+
+        Returns:
+            The url of the auth data.
+
+        Raises:
+            ValueError: When the url_getter is missing.
+
+        """
+        if not self._url_getter:
+            raise ValueError(
+                f"The file URL cannot be got because {self._repr_head()} has no url_getter"
+            )
+
+        return self._url_getter(self.path)
+
+    def open(self) -> HTTPResponse:
+        """Return the binary file pointer of this file.
+
+        Returns:
+            The cloud file pointer of this file path.
+
+        """
+        return urlopen(quote(self.get_url(), safe=printable))  # type: ignore[no-any-return]
+
+
+_DATA_SUBCLASS = (("remotePath", RemoteData), ("localPath", Data), ("cloudPath", AuthData))
