@@ -29,10 +29,11 @@ corresponding to different types of labels.
 
 """
 
+from functools import partial
 from typing import Any, Dict, Type, TypeVar, Union
 
 from ..label import LabelType
-from ..utility import EqMixin, ReprMixin, ReprType, common_loads
+from ..utility import AttrsMixin, ReprMixin, ReprType, attr, common_loads, upper
 from .label_box import Box2DSubcatalog, Box3DSubcatalog
 from .label_classification import ClassificationSubcatalog
 from .label_keypoints import Keypoints2DSubcatalog
@@ -51,7 +52,11 @@ Subcatalogs = Union[
 ]
 
 
-class Catalog(ReprMixin, EqMixin):
+_ERROR_MESSAGE = "The '{attr_name}' subcatalog is not provided in this dataset"
+_attr = partial(attr, is_dynamic=True, key=upper, error_message=_ERROR_MESSAGE)
+
+
+class Catalog(ReprMixin, AttrsMixin):
     """This class defines the concept of catalog.
 
     :class:`Catalog` is used to describe the types of labels
@@ -64,10 +69,10 @@ class Catalog(ReprMixin, EqMixin):
     contains the features, fields and the specific definitions of the labels.
 
     Examples:
-        >>> from tensorbay.utility import NameOrderedDict
+        >>> from tensorbay.utility import NameList
         >>> from tensorbay.label import ClassificationSubcatalog, CategoryInfo
         >>> classification_subcatalog = ClassificationSubcatalog()
-        >>> categories = NameOrderedDict()
+        >>> categories = NameList()
         >>> categories.append(CategoryInfo("example"))
         >>> classification_subcatalog.categories = categories
         >>> catalog = Catalog()
@@ -75,7 +80,7 @@ class Catalog(ReprMixin, EqMixin):
         >>> catalog
         Catalog(
           (classification): ClassificationSubcatalog(
-            (categories): NameOrderedDict {...}
+            (categories): NameList [...]
           )
         )
 
@@ -87,13 +92,13 @@ class Catalog(ReprMixin, EqMixin):
     _repr_attrs = tuple(label_type.value for label_type in LabelType)
     _repr_maxlevel = 2
 
-    classification: ClassificationSubcatalog
-    box2d: Box2DSubcatalog
-    box3d: Box3DSubcatalog
-    polygon2d: Polygon2DSubcatalog
-    polyline2d: Polyline2DSubcatalog
-    keypoints2d: Keypoints2DSubcatalog
-    sentence: SentenceSubcatalog
+    classification: ClassificationSubcatalog = _attr()
+    box2d: Box2DSubcatalog = _attr()
+    box3d: Box3DSubcatalog = _attr()
+    polygon2d: Polygon2DSubcatalog = _attr()
+    polyline2d: Polyline2DSubcatalog = _attr()
+    keypoints2d: Keypoints2DSubcatalog = _attr()
+    sentence: SentenceSubcatalog = _attr()
 
     def __bool__(self) -> bool:
         for label_type in LabelType:
@@ -101,11 +106,6 @@ class Catalog(ReprMixin, EqMixin):
                 return True
         return False
 
-    def _loads(self, contents: Dict[str, Any]) -> None:
-        for type_name, subcatalog in contents.items():
-            label_type = LabelType[type_name]
-            setattr(self, label_type.value, label_type.subcatalog_type.loads(subcatalog))
-
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, Any]) -> _T:
         """Load a Catalog from a dict containing the catalog information.
@@ -136,7 +136,7 @@ class Catalog(ReprMixin, EqMixin):
             >>> Catalog.loads(contents)
             Catalog(
               (classification): ClassificationSubcatalog(
-                (categories): NameOrderedDict {...}
+                (categories): NameList [...]
               ),
               (keypoints2d): Keypoints2DSubcatalog(
                 (is_tracking): False,
@@ -159,9 +159,4 @@ class Catalog(ReprMixin, EqMixin):
             {'CLASSIFICATION': {'categories': [{'name': 'example'}]}}
 
         """
-        contents: Dict[str, Any] = {}
-        for label_type in LabelType:
-            subcatalog = getattr(self, label_type.value, None)
-            if subcatalog:
-                contents[label_type.name] = subcatalog.dumps()
-        return contents
+        return self._dumps()
