@@ -25,7 +25,14 @@ with warnings.catch_warnings():
     from quaternion import quaternion
 
 from ..geometry import Box2D, Box3D, Transform3D
-from ..utility import MatrixType, ReprType, SubcatalogTypeRegister, TypeRegister, common_loads
+from ..utility import (
+    MatrixType,
+    ReprType,
+    SubcatalogTypeRegister,
+    TypeRegister,
+    attr_base,
+    common_loads,
+)
 from .basic import LabelType, SubcatalogBase, _LabelBase
 from .supports import AttributesMixin, CategoriesMixin, IsTrackingMixin
 
@@ -43,12 +50,12 @@ class Box2DSubcatalog(  # pylint: disable=too-many-ancestors
     Attributes:
         description: The description of the entire 2D box subcatalog.
         categories: All the possible categories in the corresponding dataset
-            stored in a :class:`~tensorbay.utility.name.NameOrderedDict`
+            stored in a :class:`~tensorbay.utility.name.NameList`
             with the category names as keys
             and the :class:`~tensorbay.label.supports.CategoryInfo` as values.
         category_delimiter: The delimiter in category values indicating parent-child relationship.
         attributes: All the possible attributes in the corresponding dataset
-            stored in a :class:`~tensorbay.utility.name.NameOrderedDict`
+            stored in a :class:`~tensorbay.utility.name.NameList`
             with the attribute names as keys
             and the :class:`~tensorbay.label.attribute.AttributeInfo` as values.
         is_tracking: Whether the Subcatalog contains tracking information.
@@ -68,17 +75,17 @@ class Box2DSubcatalog(  # pylint: disable=too-many-ancestors
         Box2DSubcatalog(
           (is_tracking): True,
           (category_delimiter): '.',
-          (categories): NameOrderedDict {...},
-          (attributes): NameOrderedDict {...}
+          (categories): NameList [...],
+          (attributes): NameList [...]
         )
 
         *Initialization Method 2:* Init an empty Box2DSubcatalog and then add the attributes.
 
-        >>> from tensorbay.utility import NameOrderedDict
+        >>> from tensorbay.utility import NameList
         >>> from tensorbay.label import CategoryInfo, AttributeInfo
-        >>> categories = NameOrderedDict()
+        >>> categories = NameList()
         >>> categories.append(CategoryInfo("a"))
-        >>> attributes = NameOrderedDict()
+        >>> attributes = NameList()
         >>> attributes.append(AttributeInfo("gender", enum=["female", "male"]))
         >>> box2d_subcatalog = Box2DSubcatalog()
         >>> box2d_subcatalog.is_tracking = True
@@ -89,8 +96,8 @@ class Box2DSubcatalog(  # pylint: disable=too-many-ancestors
         Box2DSubcatalog(
           (is_tracking): True,
           (category_delimiter): '.',
-          (categories): NameOrderedDict {...},
-          (attributes): NameOrderedDict {...}
+          (categories): NameList [...],
+          (attributes): NameList [...]
         )
 
     """
@@ -101,7 +108,7 @@ class Box2DSubcatalog(  # pylint: disable=too-many-ancestors
 
 
 @TypeRegister(LabelType.BOX2D)
-class LabeledBox2D(Box2D, _LabelBase):  # pylint: disable=too-many-ancestors
+class LabeledBox2D(_LabelBase, Box2D):  # pylint: disable=too-many-ancestors
     """This class defines the concept of 2D bounding box label.
 
     :class:`LabeledBox2D` is the 2D bounding box type of label,
@@ -145,6 +152,8 @@ class LabeledBox2D(Box2D, _LabelBase):  # pylint: disable=too-many-ancestors
     _repr_type = ReprType.INSTANCE
     _repr_attrs = _LabelBase._repr_attrs
 
+    _attrs_base: Box2D = attr_base(key="box2d")
+
     def __init__(
         self,
         xmin: float,
@@ -159,10 +168,6 @@ class LabeledBox2D(Box2D, _LabelBase):  # pylint: disable=too-many-ancestors
         Box2D.__init__(self, xmin, ymin, xmax, ymax)
         _LabelBase.__init__(self, category, attributes, instance)
 
-    def _loads(self, contents: Dict[str, Any]) -> None:
-        Box2D._loads(self, contents["box2d"])
-        _LabelBase._loads(self, contents)
-
     @classmethod
     def from_xywh(  # pylint: disable=arguments-differ
         cls: Type[_T],
@@ -264,9 +269,7 @@ class LabeledBox2D(Box2D, _LabelBase):  # pylint: disable=too-many-ancestors
             }
 
         """
-        contents = _LabelBase.dumps(self)
-        contents["box2d"] = Box2D.dumps(self)
-        return contents
+        return self._dumps()
 
 
 @SubcatalogTypeRegister(LabelType.BOX3D)
@@ -282,12 +285,12 @@ class Box3DSubcatalog(  # pylint: disable=too-many-ancestors
     Attributes:
         description: The description of the entire 3D box subcatalog.
         categories: All the possible categories in the corresponding dataset
-            stored in a :class:`~tensorbay.utility.name.NameOrderedDict`
+            stored in a :class:`~tensorbay.utility.name.NameList`
             with the category names as keys
             and the :class:`~tensorbay.label.supports.CategoryInfo` as values.
         category_delimiter: The delimiter in category values indicating parent-child relationship.
         attributes: All the possible attributes in the corresponding dataset
-            stored in a :class:`~tensorbay.utility.name.NameOrderedDict`
+            stored in a :class:`~tensorbay.utility.name.NameList`
             with the attribute names as keys
             and the :class:`~tensorbay.label.attribute.AttributeInfo` as values.
         is_tracking: Whether the Subcatalog contains tracking information.
@@ -307,17 +310,17 @@ class Box3DSubcatalog(  # pylint: disable=too-many-ancestors
         Box3DSubcatalog(
           (is_tracking): True,
           (category_delimiter): '.',
-          (categories): NameOrderedDict {...},
-          (attributes): NameOrderedDict {...}
+          (categories): NameList [...],
+          (attributes): NameList [...]
         )
 
         *Initialization Method 2:* Init an empty Box3DSubcatalog and then add the attributes.
 
-        >>> from tensorbay.utility import NameOrderedDict
+        >>> from tensorbay.utility import NameList
         >>> from tensorbay.label import CategoryInfo, AttributeInfo
-        >>> categories = NameOrderedDict()
+        >>> categories = NameList()
         >>> categories.append(CategoryInfo("a"))
-        >>> attributes = NameOrderedDict()
+        >>> attributes = NameList()
         >>> attributes.append(AttributeInfo("gender", enum=["female", "male"]))
         >>> box3d_subcatalog = Box3DSubcatalog()
         >>> box3d_subcatalog.is_tracking = True
@@ -328,8 +331,8 @@ class Box3DSubcatalog(  # pylint: disable=too-many-ancestors
         Box3DSubcatalog(
           (is_tracking): True,
           (category_delimiter): '.',
-          (categories): NameOrderedDict {...},
-          (attributes): NameOrderedDict {...}
+          (categories): NameList [...],
+          (attributes): NameList [...]
         )
 
     """
@@ -340,7 +343,7 @@ class Box3DSubcatalog(  # pylint: disable=too-many-ancestors
 
 
 @TypeRegister(LabelType.BOX3D)
-class LabeledBox3D(Box3D, _LabelBase):
+class LabeledBox3D(_LabelBase, Box3D):
     """This class defines the concept of 3D bounding box label.
 
     :class:`LabeledBox3D` is the 3D bounding box type of label,
@@ -387,6 +390,8 @@ class LabeledBox3D(Box3D, _LabelBase):
 
     _repr_attrs = Box3D._repr_attrs + _LabelBase._repr_attrs
 
+    _attrs_base: Box3D = attr_base(key="box3d")
+
     def __init__(
         self,
         size: Iterable[float],
@@ -414,10 +419,6 @@ class LabeledBox3D(Box3D, _LabelBase):
 
         return NotImplemented  # type: ignore[unreachable]
 
-    def _loads(self, contents: Dict[str, Any]) -> None:
-        Box3D._loads(self, contents["box3d"])
-        _LabelBase._loads(self, contents)
-
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, Any]) -> _T:
         """Loads a LabeledBox3D from a dict containing the information of the label.
@@ -480,6 +481,4 @@ class LabeledBox3D(Box3D, _LabelBase):
             }
 
         """
-        contents = _LabelBase.dumps(self)
-        contents["box3d"] = Box3D.dumps(self)
-        return contents
+        return self._dumps()
