@@ -3,18 +3,18 @@
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
 # pylint: disable=invalid-name
-
-"""Dataloader of the LISA traffic light dataset."""
+# pylint: disable=missing-module-docstring
 
 import csv
 import os
 import re
 
 from ...dataset import Data, Dataset, Segment
+from ...exception import FileStructureError
 from ...label import Classification, LabeledBox2D
 from .._utility import glob
 
-DATASET_NAME = "LISA Traffic Light"
+DATASET_NAME = "LISATrafficLight"
 
 SUPERCATEGORY_INDEX = {
     "frameAnnotationsBOX.csv": "BOX",
@@ -23,48 +23,51 @@ SUPERCATEGORY_INDEX = {
 
 
 def LISATrafficLight(path: str) -> Dataset:
-    """Dataloader of the LISA traffic light dataset.
+    """Dataloader of the `LISA Traffic Light`_ dataset.
+
+    .. _LISA Traffic Light: http://cvrr.ucsd.edu/LISA/datasets.html
+
+    The file structure should be like::
+
+        <path>
+            Annotations/Annotations/
+                daySequence1/
+                daySequence2/
+                dayTrain/
+                    dayClip1/
+                    dayClip10/
+                    ...
+                    dayClip9/
+                nightSequence1/
+                nightSequence2/
+                nightTrain/
+                    nightClip1/
+                    nightClip2/
+                    ...
+                    nightClip5/
+            daySequence1/daySequence1/
+            daySequence2/daySequence2/
+            dayTrain/dayTrain/
+                dayClip1/
+                dayClip10/
+                ...
+                dayClip9/
+            nightSequence1/nightSequence1/
+            nightSequence2/nightSequence2/
+            nightTrain/nightTrain/
+                nightClip1/
+                nightClip2/
+                ...
+                nightClip5/
 
     Arguments:
         path: The root directory of the dataset.
-            The file structure should be like::
-
-                <path>
-                    Annotations/Annotations/
-                        daySequence1/
-                        daySequence2/
-                        dayTrain/
-                            dayClip1/
-                            dayClip10/
-                            ...
-                            dayClip9/
-                        nightSequence1/
-                        nightSequence2/
-                        nightTrain/
-                            nightClip1/
-                            nightClip2/
-                            ...
-                            nightClip5/
-                    daySequence1/daySequence1/
-                    daySequence2/daySequence2/
-                    dayTrain/dayTrain/
-                        dayClip1/
-                        dayClip10/
-                        ...
-                        dayClip9/
-                    nightSequence1/nightSequence1/
-                    nightSequence2/nightSequence2/
-                    nightTrain/nightTrain/
-                        nightClip1/
-                        nightClip2/
-                        ...
-                        nightClip5/
 
     Returns:
-        Loaded `Dataset` object.
+        Loaded :class:`~tensorbay.dataset.dataset.Dataset` instance.
 
     Raises:
-        TypeError: When frame number is discontinuous.
+        FileStructureError: When frame number is discontinuous.
 
     """
     root_path = os.path.abspath(os.path.expanduser(path))
@@ -87,7 +90,7 @@ def LISATrafficLight(path: str) -> Dataset:
 
         # Check the frame_number from filename: "daySequence1--00345.jpg"
         if _get_frame_number(image_paths[-1]) + 1 != len(image_paths):
-            raise TypeError(f"Discontinuous frame number in '{filedir}'")
+            raise FileStructureError(f"Discontinuous frame number in '{filedir}'")
 
         for image_path in image_paths:
             data = Data(image_path)
@@ -116,7 +119,7 @@ def _get_segment_name(csv_path: str) -> str:
     with open(csv_path, "r", encoding="utf-8") as fp:
         reader = csv.DictReader(fp, delimiter=";")
         first_filename = next(reader)["Filename"]
-        header = first_filename[: first_filename.index("-")]
+        header = first_filename[: first_filename.index("-")].replace("/", "-")
         return re.sub(r"\d+", lambda match: f"{int(match.group(0)):02}", header, 1)
 
 
